Tooz
====

The Tooz project aims at centralizing the most common distributed primitives
like group membership protocol, lock service and leader election by providing
a coordination API helping developers to build distributed applications.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/tooz
* Source: http://git.openstack.org/cgit/openstack/tooz
* Bugs: http://bugs.launchpad.net/python-tooz/

Join us
-------

- http://launchpad.net/python-tooz
